import { world, ItemStack, EquipmentSlot, EntityComponentTypes } from "@minecraft/server";

world.afterEvents.itemUse.subscribe(async (eventData) => {
    const player = eventData.source;

    // Get the item in the player's main hand
    const mainHandSlotIndex = player.selectedSlotIndex;
    const mainHandItem = player.getComponent("minecraft:inventory").container.getItem(mainHandSlotIndex);
    
    // Get the item in the offhand slot
    const equipmentCompPlayer = player.getComponent(EntityComponentTypes.Equippable);
    if (equipmentCompPlayer) {
        const offHandItem = equipmentCompPlayer.getEquipment(EquipmentSlot.Offhand);

        // Check for main hand item durability and tags
        if (mainHandItem && mainHandItem.hasComponent("minecraft:durability")) {
            const durabilityComponent = mainHandItem.getComponent("minecraft:durability");
            const maxDurability = durabilityComponent.maxDurability;
            const currentDurability = durabilityComponent.damage;

            // Proceed if the item has damage (is not fully repaired)
            if (currentDurability > 0) {
                let repairKitUsed = false;

// Handle wooden tier tools, bows, and crossbows
if ((mainHandItem.hasTag("minecraft:is_tool") &&
     mainHandItem.hasTag("minecraft:wooden_tier")) ||
    mainHandItem.typeId === "minecraft:bow" ||
    mainHandItem.typeId === "minecraft:crossbow") {

    if (offHandItem && offHandItem.typeId === "srk:wood_repair_kit") {
        repairKitUsed = true;
        const durabilityToAdd = Math.floor(maxDurability * 0.20);
        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

        if (offHandItem.hasComponent("minecraft:durability")) {
            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
            offHandDurabilityComponent.damage += 1;

            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                player.playSound("random.break");
            } else {
                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
            }
        }

        // Play the smithing table use sound
        player.playSound("smithing_table.use");
    }
}
                // Handle stone tier tools
                if (mainHandItem.hasTag("minecraft:is_tool") &&
                    mainHandItem.hasTag("minecraft:stone_tier")) {

                    if (offHandItem && offHandItem.typeId === "srk:stone_repair_kit") {
                        repairKitUsed = true;
                        const durabilityToAdd = Math.floor(maxDurability * 0.20);
                        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
                        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

                        if (offHandItem.hasComponent("minecraft:durability")) {
                            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
                            offHandDurabilityComponent.damage += 1;

                            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                                player.playSound("random.break");
                            } else {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
                            }
                        }

                        // Play the smithing table use sound
                        player.playSound("smithing_table.use");
                    }
                }

                // Handle iron tier tools and shields
                if ((mainHandItem.hasTag("minecraft:is_tool") &&
                     mainHandItem.hasTag("minecraft:iron_tier")) ||
                    mainHandItem.typeId === "minecraft:shield") {

                    if (offHandItem && offHandItem.typeId === "srk:iron_repair_kit") {
                        repairKitUsed = true;
                        const durabilityToAdd = Math.floor(maxDurability * 0.20);
                        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
                        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

                        if (offHandItem.hasComponent("minecraft:durability")) {
                            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
                            offHandDurabilityComponent.damage += 1;

                            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                                player.playSound("random.break");
                            } else {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
                            }
                        }

                        // Play the smithing table use sound
                        player.playSound("smithing_table.use");
                    }
                }

                // Handle golden tier tools
                if (mainHandItem.hasTag("minecraft:is_tool") &&
                    mainHandItem.hasTag("minecraft:golden_tier")) {

                    if (offHandItem && offHandItem.typeId === "srk:gold_repair_kit") {
                        repairKitUsed = true;
                        const durabilityToAdd = Math.floor(maxDurability * 0.20);
                        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
                        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

                        if (offHandItem.hasComponent("minecraft:durability")) {
                            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
                            offHandDurabilityComponent.damage += 1;

                            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                                player.playSound("random.break");
                            } else {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
                            }
                        }

                        // Play the smithing table use sound
                        player.playSound("smithing_table.use");
                    }
                }

                // Handle diamond tier tools and tridents
                if ((mainHandItem.hasTag("minecraft:is_tool") &&
                     mainHandItem.hasTag("minecraft:diamond_tier")) ||
                    mainHandItem.typeId === "minecraft:trident") {

                    if (offHandItem && offHandItem.typeId === "srk:diamond_repair_kit") {
                        repairKitUsed = true;
                        const durabilityToAdd = Math.floor(maxDurability * 0.20);
                        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
                        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

                        if (offHandItem.hasComponent("minecraft:durability")) {
                            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
                            offHandDurabilityComponent.damage += 1;

                            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                                player.playSound("random.break");
                            } else {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
                            }
                        }

                        // Play the smithing table use sound
                        player.playSound("smithing_table.use");
                    }
                }

                // Handle netherite tier tools
                if (mainHandItem.hasTag("minecraft:is_tool") &&
                    mainHandItem.hasTag("minecraft:netherite_tier")) {

                    if (offHandItem && offHandItem.typeId === "srk:netherite_repair_kit") {
                        repairKitUsed = true;
                        const durabilityToAdd = Math.floor(maxDurability * 0.20);
                        durabilityComponent.damage = Math.max(currentDurability - durabilityToAdd, 0);
                        player.getComponent("minecraft:inventory").container.setItem(mainHandSlotIndex, mainHandItem);

                        if (offHandItem.hasComponent("minecraft:durability")) {
                            const offHandDurabilityComponent = offHandItem.getComponent("minecraft:durability");
                            offHandDurabilityComponent.damage += 1;

                            if (offHandDurabilityComponent.damage >= offHandDurabilityComponent.maxDurability) {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, null);
                                player.playSound("random.break");
                            } else {
                                equipmentCompPlayer.setEquipment(EquipmentSlot.Offhand, offHandItem);
                            }
                        }

                        // Play the smithing table use sound
                        player.playSound("smithing_table.use");
                    }
                }

                // If no repair kit was used, do nothing.
                if (!repairKitUsed) {
                    // Do nothing
                }
            } else {
                // Check if the offhand item is one of the repair kits
                if (offHandItem &&
                    (offHandItem.typeId === "srk:wood_repair_kit" ||
                     offHandItem.typeId === "srk:stone_repair_kit" ||
                     offHandItem.typeId === "srk:iron_repair_kit" ||
                     offHandItem.typeId === "srk:gold_repair_kit" ||
                     offHandItem.typeId === "srk:diamond_repair_kit" ||
                     offHandItem.typeId === "srk:netherite_repair_kit")) {
                    // The item is at full durability
                    await player.runCommandAsync(`/title @s actionbar The item is already at full durability, or you're using an inadequate repair kit.`);
                }
            }
        } else {
            console.warn('No durability component found on main hand item');
        }
    } else {
        console.warn('No equipment component found on player');
    }
});

